package burp.vaycore.onescan.manager;

import burp.vaycore.common.helper.DomainHelper;
import burp.vaycore.common.log.Logger;
import burp.vaycore.common.utils.ClassUtils;
import burp.vaycore.common.utils.FileUtils;
import burp.vaycore.common.utils.StringUtils;
import burp.vaycore.common.utils.Utils;
import burp.vaycore.onescan.bean.CollectNode;
import burp.vaycore.onescan.bean.CollectReqResp;
import burp.vaycore.onescan.collect.JsonFieldCollect;
import burp.vaycore.onescan.collect.WebNameCollect;
import java.io.File;
import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import javax.swing.SwingUtilities;

public class CollectManager {

   private static final Class[] sModules = new Class[]{JsonFieldCollect.class, WebNameCollect.class};
   private static Map sCollectData;
   private static final Set sRepeatFilter = Collections.synchronizedSet(new HashSet());
   private static String sDirPath;
   private static ExecutorService sThreadPool;
   private static CollectManager.CollectNodeListener sCollectNodeListener;
   private static Map sModuleMap;


   private CollectManager() {
      throw new IllegalAccessError("manager class not support create instance.");
   }

   public static void init(String dirPath) {
      if(StringUtils.isEmpty(dirPath)) {
         throw new IllegalArgumentException("collect directory is empty.");
      } else {
         if(!FileUtils.exists(dirPath)) {
            FileUtils.mkdirs(dirPath);
         }

         if(!FileUtils.isDir(dirPath)) {
            throw new IllegalArgumentException("collect directory not found.");
         } else {
            sThreadPool = Executors.newFixedThreadPool(10);
            sModuleMap = new HashMap();
            sDirPath = dirPath;
            loadData();
            invokeNodeInitEvent();
         }
      }
   }

   private static void loadData() {
      sCollectData = new HashMap();
      CollectNode root = createOrGetNode("/", "All");
      File dir = new File(sDirPath);
      File[] parentFiles = dir.listFiles(accept<invokedynamic>());
      if(parentFiles != null && parentFiles.length != 0) {
         File[] var3 = parentFiles;
         int var4 = parentFiles.length;

         for(int var5 = 0; var5 < var4; ++var5) {
            File parentFile = var3[var5];
            File[] hostDirs = parentFile.listFiles(accept<invokedynamic>());
            if(hostDirs != null && hostDirs.length != 0) {
               String parentName = parentFile.getName();
               CollectNode parentNode = createOrGetNode("/" + parentName, parentName);
               root.add(parentNode);
               File[] var10 = hostDirs;
               int var11 = hostDirs.length;

               for(int var12 = 0; var12 < var11; ++var12) {
                  File hostDir = var10[var12];
                  String[] dataFiles = hostDir.list();
                  if(dataFiles != null && dataFiles.length != 0) {
                     String hostName = hostDir.getName();
                     CollectNode node = createOrGetNode("/" + parentName + "/" + hostName, hostName);
                     parentNode.add(node);
                     forEachModule(onAcceptModule<invokedynamic>(hostDir, node));
                  }
               }
            }
         }

      }
   }

   public static void collect(boolean isRequest, String host, byte[] rawBytes) {
      checkInit();
      if(host != null && !StringUtils.isEmpty(host.trim())) {
         sThreadPool.execute(run<invokedynamic>(rawBytes, isRequest, host));
      }
   }

   private static void doSaveData(String host, String moduleName, List data) {
      CollectNode root = createOrGetNode("/", "All");
      String parentName = DomainHelper.getDomain(host, (String)null);
      if(parentName == null) {
         parentName = "ip";
      }

      CollectNode parentNode = createOrGetNode("/" + parentName, parentName);
      root.add(parentNode);
      String nodePath = "/" + parentName + "/" + host;
      boolean nodeExists = getNodeByPath(nodePath) != null;
      CollectNode node = createOrGetNode(nodePath, host);
      parentNode.add(node);
      if(!nodeExists) {
         invokeNodeCreateEvent(nodePath, node);
      }

      List diff = node.putData(moduleName, data);
      if(!diff.isEmpty()) {
         String saveDir = sDirPath + File.separator + parentName + File.separator + host + File.separator;
         if(!FileUtils.exists(saveDir)) {
            FileUtils.mkdirs(saveDir);
         }

         String savePath = saveDir + moduleName + ".txt";
         String content = StringUtils.join(diff, "\n") + "\n";
         FileUtils.writeFile(savePath, content, true);
      }
   }

   public static void forEachModule(CollectManager.ModuleCallback callback) {
      checkInit();
      if(callback != null) {
         Class[] var1 = sModules;
         int var2 = var1.length;

         for(int var3 = 0; var3 < var2; ++var3) {
            Class moduleClz = var1[var3];
            CollectManager.ICollectModule module = getModuleByClass(moduleClz);
            if(module != null) {
               callback.onAcceptModule(module);
            }
         }

      }
   }

   public static CollectNode getNodeByPath(String nodePath) {
      checkInit();
      return sCollectData.containsKey(nodePath)?(CollectNode)sCollectData.get(nodePath):null;
   }

   public static void delNodeByPath(String nodePath) {
      if(!StringUtils.isEmpty(nodePath) && sCollectData.containsKey(nodePath)) {
         CollectNode node = (CollectNode)sCollectData.remove(nodePath);
         node.clearNode();
         if(nodePath.equals("/")) {
            sCollectData.clear();
            createOrGetNode("/", "All");
         } else {
            CollectNode e = node.getParent();
            e.removeNode(node);
            if(!node.isNodesEmpty()) {
               sCollectData.forEach(accept<invokedynamic>(nodePath));
            } else {
               CollectNode root = createOrGetNode("/", "All");
               root.removeNode(e);
            }
         }

         try {
            String e1 = (new File(sDirPath, nodePath)).getCanonicalPath();
            if(!e1.startsWith(sDirPath)) {
               Logger.error("delete node path exception: " + nodePath);
               return;
            }

            FileUtils.deleteFile(e1);
            if("/".equals(nodePath)) {
               FileUtils.mkdirs(sDirPath);
            }
         } catch (Exception var4) {
            Logger.error("delete node error: " + var4.getMessage());
         }

      }
   }

   public static void setCollectNodeListener(CollectManager.CollectNodeListener l) {
      sCollectNodeListener = l;
   }

   private static void invokeNodeInitEvent() {
      SwingUtilities.invokeLater(run<invokedynamic>());
   }

   private static void invokeNodeCreateEvent(String nodePath, CollectNode node) {
      SwingUtilities.invokeLater(run<invokedynamic>(nodePath, node));
   }

   private static void checkInit() {
      if(StringUtils.isEmpty(sDirPath) || !FileUtils.isDir(sDirPath) || sCollectData == null) {
         throw new IllegalArgumentException("CollectManager no init.");
      }
   }

   private static CollectNode createOrGetNode(String nodePath, String nodeName) {
      checkInit();
      if(sCollectData.containsKey(nodePath)) {
         return (CollectNode)sCollectData.get(nodePath);
      } else {
         CollectNode node = new CollectNode(nodeName);
         sCollectData.put(nodePath, node);
         return node;
      }
   }

   private static CollectManager.ICollectModule getModuleByClass(Class moduleClz) {
      String clzName = moduleClz.getName();
      CollectManager.ICollectModule module;
      if(sModuleMap.containsKey(clzName)) {
         module = (CollectManager.ICollectModule)sModuleMap.get(clzName);
      } else {
         module = (CollectManager.ICollectModule)ClassUtils.newObjectByClass(moduleClz);
         if(module == null) {
            return null;
         }

         sModuleMap.put(clzName, module);
      }

      return module;
   }

   public static void clearRepeatFilter() {
      if(!sRepeatFilter.isEmpty()) {
         sRepeatFilter.clear();
      }

   }

   public static int getRepeatFilterCount() {
      return sRepeatFilter.size();
   }

   public static int closeThreadPool() {
      return sThreadPool.shutdownNow().size();
   }

   // $FF: synthetic method
   private static void lambda$invokeNodeCreateEvent$5(String nodePath, CollectNode node) {
      if(sCollectNodeListener != null) {
         sCollectNodeListener.onNodeCreate(nodePath, node);
      }

   }

   // $FF: synthetic method
   private static void lambda$invokeNodeInitEvent$4() {
      if(sCollectNodeListener != null) {
         sCollectNodeListener.onNodeInit();
      }

   }

   // $FF: synthetic method
   private static void lambda$delNodeByPath$3(String nodePath, String key, CollectNode value) {
      String suffixNodePath = nodePath + "/";
      if(key.startsWith(suffixNodePath)) {
         sCollectData.remove(key);
      }

   }

   // $FF: synthetic method
   private static void lambda$collect$2(byte[] rawBytes, boolean isRequest, String host) {
      String tempKey = Utils.md5(rawBytes);
      if(!sRepeatFilter.contains(tempKey)) {
         CollectReqResp reqResp = new CollectReqResp(isRequest, rawBytes);
         forEachModule(onAcceptModule<invokedynamic>(reqResp, host));
         sRepeatFilter.add(tempKey);
      }
   }

   // $FF: synthetic method
   private static void lambda$null$1(CollectReqResp reqResp, String host, CollectManager.ICollectModule module) {
      List data = module.doCollect(reqResp);
      if(data != null && !data.isEmpty()) {
         doSaveData(host, module.getName(), data);
      }
   }

   // $FF: synthetic method
   private static void lambda$loadData$0(File hostDir, CollectNode node, CollectManager.ICollectModule module) {
      String moduleName = module.getName();
      File dataFile = new File(hostDir, moduleName + ".txt");
      ArrayList dataSet;
      if(!dataFile.exists()) {
         dataSet = new ArrayList();
      } else {
         dataSet = FileUtils.readFileToList(dataFile);
      }

      node.putData(module.getName(), dataSet);
   }


   public interface CollectNodeListener {

      void onNodeInit();

      void onNodeCreate(String var1, CollectNode var2);
   }

   public interface ModuleCallback {

      void onAcceptModule(CollectManager.ICollectModule var1);
   }

   public interface ICollectModule {

      String getName();

      List doCollect(CollectReqResp var1);
   }
}
